==> zxing_lib-0.9.0.tar.gz: lib/client.dart <==
/// decode parsers and results
library zxing_lib.client;

export 'src/client/result/abstract_do_co_mo_result_parser.dart';
export 'src/client/result/address_book_auresult_parser.dart';
export 'src/client/result/address_book_do_co_mo_result_parser.dart';
export 'src/client/result/address_book_parsed_result.dart';
export 'src/client/result/bizcard_result_parser.dart';
export 'src/client/result/bookmark_do_co_mo_result_parser.dart';
export 'src/client/result/calendar_parsed_result.dart';
export 'src/client/result/email_address_parsed_result.dart';
export 'src/client/result/email_address_result_parser.dart';
export 'src/client/result/email_do_co_mo_result_parser.dart';
export 'src/client/result/expanded_product_parsed_result.dart';
export 'src/client/result/expanded_product_result_parser.dart';
export 'src/client/result/geo_parsed_result.dart';
export 'src/client/result/geo_result_parser.dart';
export 'src/client/result/isbnparsed_result.dart';
export 'src/client/result/isbnresult_parser.dart';
export 'src/client/result/parsed_result.dart';
export 'src/client/result/parsed_result_type.dart';
export 'src/client/result/product_parsed_result.dart';
export 'src/client/result/product_result_parser.dart';
export 'src/client/result/result_parser.dart';
export 'src/client/result/smsmmsresult_parser.dart';
export 'src/client/result/smsparsed_result.dart';
export 'src/client/result/smstommstoresult_parser.dart';
export 'src/client/result/smtpresult_parser.dart';
export 'src/client/result/tel_parsed_result.dart';
export 'src/client/result/tel_result_parser.dart';
export 'src/client/result/text_parsed_result.dart';
export 'src/client/result/uriparsed_result.dart';
export 'src/client/result/uriresult_parser.dart';
export 'src/client/result/urltoresult_parser.dart';
export 'src/client/result/vcard_result_parser.dart';
export 'src/client/result/vevent_result_parser.dart';
export 'src/client/result/vinparsed_result.dart';
export 'src/client/result/vinresult_parser.dart';
export 'src/client/result/wifi_parsed_result.dart';
export 'src/client/result/wifi_result_parser.dart';

==> zxing_lib-1.1.1.tar.gz: lib/client.dart <==
/// decode parsers and results
library zxing_lib.client;

export 'src/client/result/abstract_do_co_mo_result_parser.dart';
export 'src/client/result/address_book_auresult_parser.dart';
export 'src/client/result/address_book_do_co_mo_result_parser.dart';
export 'src/client/result/address_book_parsed_result.dart';
export 'src/client/result/bizcard_result_parser.dart';
export 'src/client/result/bookmark_do_co_mo_result_parser.dart';
export 'src/client/result/calendar_parsed_result.dart';
export 'src/client/result/email_address_parsed_result.dart';
export 'src/client/result/email_address_result_parser.dart';
export 'src/client/result/email_do_co_mo_result_parser.dart';
export 'src/client/result/expanded_product_parsed_result.dart';
export 'src/client/result/expanded_product_result_parser.dart';
export 'src/client/result/geo_parsed_result.dart';
export 'src/client/result/geo_result_parser.dart';
export 'src/client/result/isbn_parsed_result.dart';
export 'src/client/result/isbn_result_parser.dart';
export 'src/client/result/parsed_result.dart';
export 'src/client/result/parsed_result_type.dart';
export 'src/client/result/product_parsed_result.dart';
export 'src/client/result/product_result_parser.dart';
export 'src/client/result/result_parser.dart';
export 'src/client/result/sms_mms_result_parser.dart';
export 'src/client/result/sms_parsed_result.dart';
export 'src/client/result/smsto_mmsto_result_parser.dart';
export 'src/client/result/smtp_result_parser.dart';
export 'src/client/result/tel_parsed_result.dart';
export 'src/client/result/tel_result_parser.dart';
export 'src/client/result/text_parsed_result.dart';
export 'src/client/result/uri_parsed_result.dart';
export 'src/client/result/uri_result_parser.dart';
export 'src/client/result/urlto_result_parser.dart';
export 'src/client/result/vcard_result_parser.dart';
export 'src/client/result/vevent_result_parser.dart';
export 'src/client/result/vin_parsed_result.dart';
export 'src/client/result/vin_result_parser.dart';
export 'src/client/result/wifi_parsed_result.dart';
export 'src/client/result/wifi_result_parser.dart';
